==> ochusha_0.5.4.10-1_source_deb.tar.gz: ochusha-0.5.4.10/gtk2/ochusha_ui_private.h <==
/*
 * Copyright (c) 2003-2004 The Ochusha Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: ochusha_ui_private.h,v 1.11.2.5 2004/06/16 05:29:45 fuyu Exp $
 */

#ifndef _OCHUSHA_UI_PRIVATE_H_
#define _OCHUSHA_UI_PRIVATE_H_

#ifdef USE_GTK22_API
/* ʡad-hocн */
#undef GTK_DISABLE_DEPRECATED
#include <gtk/gtk.h>
#undef GTK_MINOR_VERSION
#define GTK_MINOR_VERSION 2
#endif

#include <pthread.h>

#ifdef __cplusplus
extern "C" {
#endif

#define DEBUG_GUI			0
#define DEBUG_GUI_MOST			0
#define DEBUG_THREAD			0
#define DEBUG_THREAD_MOST		0
#define DEBUG_WIDGET			0
#define DEBUG_WIDGET_MOST		0

#define DEBUG_TS_ENGINE			0

#define ENABLE_STRICT_CHECK		0
#define USE_THREAD_FOR_MAIN		0

#define GRAB_FOCUS_ON_ENTER_NOTIFY	0


#ifdef __cplusplus
} // extern "C"
#endif

#endif	/* _OCHUSHA_UI_PRIVATE_H_ */

==> ochusha_0.5.6-1_source_deb.tar.gz: ochusha-0.5.6/gtk2/ochusha_ui_private.h <==
/*
 * Copyright (c) 2003-2004 The Ochusha Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: ochusha_ui_private.h,v 1.11.2.7 2004/11/13 12:40:52 fuyu Exp $
 */

#ifndef _OCHUSHA_UI_PRIVATE_H_
#define _OCHUSHA_UI_PRIVATE_H_

#ifdef USE_GTK22_API
/* ʡad-hocн */
#undef GTK_DISABLE_DEPRECATED
#include <gtk/gtk.h>
#undef GTK_MINOR_VERSION
#define GTK_MINOR_VERSION 2
#endif

#include <pthread.h>

#ifdef __cplusplus
extern "C" {
#endif

#define DEBUG_GUI			0
#define DEBUG_GUI_MOST			0
#define DEBUG_THREAD			0
#define DEBUG_THREAD_MOST		0
#define DEBUG_WIDGET			0
#define DEBUG_WIDGET_MOST		0

#define DEBUG_TS_ENGINE			0

#define ENABLE_STRICT_CHECK		0
#define USE_THREAD_FOR_MAIN		0

#define GRAB_FOCUS_ON_ENTER_NOTIFY	1


#if ENABLE_STRICT_CHECK
void ochusha_ensure_gdk_threads_entered(void);
#endif

#ifndef _OCHUSHA_UI_C_
extern GQuark application_id;
#endif

#ifdef __cplusplus
} // extern "C"
#endif

#endif	/* _OCHUSHA_UI_PRIVATE_H_ */
